@@ -5,7 +5,7 @@ import types
 from typing import Any, Callable
 from inspect import iscoroutinefunction
 
-class ResultException(BaseException):
+class ResultException(Exception):
     pass
 
 
@@ -78,14 +78,14 @@ class ResultType(_ResultType):
                     try:
                         v = await fn(*args, **kwargs)
                         return Ok[V](v)
-                    except BaseException as e: #  TODO check it was Exception not BaseException
+                    except Exception as e:
                         return Err[E](e)
             elif callable(fn):
                 def wrap(*args, **kwargs) -> Any:
                     try:
                         v = fn(*args, **kwargs)
                         return Ok[V](v)
-                    except BaseException as e: #  TODO check it was Exception not BaseException
+                    except Exception as e:
                         return Err[E](e)
 
             return wrap
@@ -162,7 +162,7 @@ class Err(Result):
         if not (isinstance(E, types.GenericAlias)
                 or isinstance(E, str)
                 or E is Any
-                or isinstance(e, (E, BaseException))):
+                or isinstance(e, (E, Exception))):
             raise TypeError(f'Got {type(e)} but expected {self.__class__.__annotations__["e"]}')
 
         self.e = e
@@ -172,7 +172,7 @@ class Err(Result):
         """
         This function unwrap and raise exception of Error type of Err type of Result
         """
-        if not isinstance(self.e, BaseException):
+        if not isinstance(self.e, Exception):
             e = ResultException(self.e)
         else:
             e = self.e # pragma: no cover
@@ -205,14 +205,14 @@ def wrap_result(res: Result):
                     try:
                         v = await f(*args, **kwargs)
                         return Ok(v)
-                    except BaseException as e: #  TODO check it was Exception not BaseException
+                    except Exception as e:
                         return Err(e)  
                 return a()
             else:
                 try:
                     v = f(*args, **kwargs)
                     return Ok(v)
-                except BaseException as e: #  TODO check it was Exception not BaseException
+                except Exception as e:
                     return Err(e)
 
         return inner
